@@ -138,40 +138,40 @@ caseParseRequestBody = do
 
     it "exceeding number of files" $ do
         SRequest req4 _bod4 <- toRequest'' ctype3 content3
-        (parseRequestBodyEx (setMaxRequestNumFiles 0 def) lbsBackEnd req4)
+        parseRequestBodyEx (setMaxRequestNumFiles 0 def) lbsBackEnd req4
             `shouldThrow` anyException
 
     it "exceeding parameter length" $ do
         SRequest req4 _bod4 <- toRequest'' ctype3 content3
-        (parseRequestBodyEx (setMaxRequestKeyLength 2 def) lbsBackEnd req4)
+        parseRequestBodyEx (setMaxRequestKeyLength 2 def) lbsBackEnd req4
             `shouldThrow` anyException
 
     it "exceeding file size" $ do
         SRequest req4 _bod4 <- toRequest'' ctype3 content3
-        (parseRequestBodyEx (setMaxRequestFileSize 2 def) lbsBackEnd req4)
+        parseRequestBodyEx (setMaxRequestFileSize 2 def) lbsBackEnd req4
             `shouldThrow` (== PayloadTooLarge)
 
     it "exceeding total file size" $ do
         SRequest req4 _bod4 <- toRequest'' ctype3 content3
-        (parseRequestBodyEx (setMaxRequestFilesSize 20 def) lbsBackEnd req4)
+        parseRequestBodyEx (setMaxRequestFilesSize 20 def) lbsBackEnd req4
             `shouldThrow` (== PayloadTooLarge)
         SRequest req5 _bod5 <- toRequest'' ctype3 content5
-        (parseRequestBodyEx (setMaxRequestFilesSize 20 def) lbsBackEnd req5)
+        parseRequestBodyEx (setMaxRequestFilesSize 20 def) lbsBackEnd req5
             `shouldThrow` (== PayloadTooLarge)
 
     it "exceeding max parm value size" $ do
         SRequest req4 _bod4 <- toRequest'' ctype2 content2
-        (parseRequestBodyEx (setMaxRequestParmsSize 10 def) lbsBackEnd req4)
+        parseRequestBodyEx (setMaxRequestParmsSize 10 def) lbsBackEnd req4
             `shouldThrow` (== PayloadTooLarge)
 
     it "exceeding max header lines" $ do
         SRequest req4 _bod4 <- toRequest'' ctype2 content2
-        (parseRequestBodyEx (setMaxHeaderLines 1 def) lbsBackEnd req4)
+        parseRequestBodyEx (setMaxHeaderLines 1 def) lbsBackEnd req4
             `shouldThrow` anyException
 
     it "exceeding header line size" $ do
         SRequest req4 _bod4 <- toRequest'' ctype3 content4
-        (parseRequestBodyEx (setMaxHeaderLineLength 8190 def) lbsBackEnd req4)
+        parseRequestBodyEx (setMaxHeaderLineLength 8190 def) lbsBackEnd req4
             `shouldThrow` (== RequestHeaderFieldsTooLarge)
 
     it "Testing parseRequestBodyEx with application/x-www-form-urlencoded" $ do
@@ -195,8 +195,18 @@ caseParseRequestBody = do
                 "thisisalongparameterkey=andthisbeanevenlongerparametervaluehelloworldhowareyou"
         let ctype = "application/x-www-form-urlencoded"
         SRequest req _bod <- toRequest'' ctype content
-        (parseRequestBodyEx (setMaxRequestParmsSize 10 def) lbsBackEnd req)
+        parseRequestBodyEx (setMaxRequestParmsSize 10 def) lbsBackEnd req
             `shouldThrow` anyException
+    it "parsing filename with semi-colon" $ do
+        SRequest req _bod <- toRequest'' ctype3 content6
+        let expected = ([], [("yaml", FileInfo "semi; colon;" "application/octet-stream" "Photo blog using Hack.\n")])
+        body <- parseRequestBodyEx def lbsBackEnd req
+        body `shouldBe` expected
+    it "parsing filename with semi-colon" $ do
+        SRequest req _bod <- toRequest'' ctype3 content7
+        let expected = ([], [("yaml", FileInfo "this will be dropped, !only this will be returned" "application/octet-stream" "Photo blog using Hack.\n")])
+        body <- parseRequestBodyEx def lbsBackEnd req
+        body `shouldBe` expected
   where
     content2 =
         "--AaB03x\n"
@@ -242,6 +252,18 @@ caseParseRequestBody = do
             <> "Content-Type: application/octet-stream\r\n\r\n"
             <> "Photo blog using Hack.\n\r\n"
             <> "------WebKitFormBoundaryB1pWXPZ6lNr8RiLh--\r\n"
+    content6 =
+        "------WebKitFormBoundaryB1pWXPZ6lNr8RiLh\r\n"
+            <> "Content-Disposition: form-data; name=\"yaml\"; filename=\"semi; colon;\"\r\n"
+            <> "Content-Type: application/octet-stream\r\n\r\n"
+            <> "Photo blog using Hack.\n\r\n"
+            <> "------WebKitFormBoundaryB1pWXPZ6lNr8RiLh\r\n"
+    content7 =
+        "------WebKitFormBoundaryB1pWXPZ6lNr8RiLh\r\n"
+            <> "Content-Disposition: form-data; name=\"yaml\"; filename=\"this will be dropped, \\!only this will be returned\r\n"
+            <> "Content-Type: application/octet-stream\r\n\r\n"
+            <> "Photo blog using Hack.\n\r\n"
+            <> "------WebKitFormBoundaryB1pWXPZ6lNr8RiLh\r\n"
 
 caseMultipartPlus :: Assertion
 caseMultipartPlus = do
